@@ -323,6 +323,10 @@ class GSPeerConnectionBroadcasterPiSocketv2:
         @self.sio.event
         async def broadcaster(id, description,emitter):
 
+            if emitter == "watcher":
+                return
+
+
             if len(self.rtconfiList) > 0:
                 pc = RTCPeerConnection(configuration=RTCConfiguration(self.rtconfiList))
             else:
